@@ -64,6 +64,7 @@ import sys
 import time
 import unittest
 from datetime import datetime, timedelta
+from pkg_resources import parse_version
 
 import trac
 from trac.tests.compat import rmtree
@@ -85,12 +86,6 @@ try:
 except ImportError:
     has_svn = False
 
-try:
-    from configobj import ConfigObj
-except ImportError:
-    ConfigObj = None
-    print "SKIP: fine-grained permission tests (ConfigObj not installed)"
-
 from trac.test import TestSetup, TestCaseSetup
 from trac.tests.contentgen import random_sentence, random_page, random_word, \
     random_unique_camel
@@ -99,14 +94,7 @@ internal_error = 'Trac detected an internal error:'
 
 trac_source_tree = os.path.normpath(os.path.join(trac.__file__, '..', '..'))
 
-# testing.log gets any unused output from subprocesses
-logfile = open(os.path.join(trac_source_tree, 'testing.log'), 'w')
-
 if twill:
-    # functional-testing.log gets the twill output
-    twill.set_output(open(os.path.join(trac_source_tree,
-                                       'functional-testing.log'), 'w'))
-
     from trac.tests.functional.testenv import FunctionalTestEnvironment
     from trac.tests.functional.svntestenv import SvnFunctionalTestEnvironment
 
@@ -125,6 +113,12 @@ if twill:
 
         tester_class = FunctionalTester
 
+        def __init__(self):
+            if parse_version(twill.__version__) != parse_version('0.9'):
+                raise ImportError("Twill 0.9 is required. Found version %s."
+                                  % twill.__version__)
+            super(FunctionalTestSuite, self).__init__()
+
         def setUp(self, port=None):
             """If no port is specified, use a semi-random port and subdirectory
             'testenv'; but if a port is specified, use that port and
@@ -148,6 +142,12 @@ if twill:
 
             baseurl = "http://127.0.0.1:%s" % port
             self._testenv = self.env_class(env_path, port, baseurl)
+
+            # functional-testing.log gets the twill output
+            self.functional_test_log = \
+                os.path.join(env_path, 'functional-testing.log')
+            twill.set_output(open(self.functional_test_log, 'w'))
+
             self._testenv.start()
             self._tester = self.tester_class(baseurl)
             self.fixture = (self._testenv, self._tester)
@@ -190,7 +190,7 @@ def functionalSuite():
     return suite
 
 
-def suite():
+def test_suite():
     try:
         suite = functionalSuite()
         import trac.tests.functional.testcases
@@ -199,6 +199,8 @@ def suite():
         trac.versioncontrol.tests.functionalSuite(suite)
         import trac.ticket.tests
         trac.ticket.tests.functionalSuite(suite)
+        import trac.mimeview.tests
+        trac.mimeview.tests.functionalSuite(suite)
         import trac.prefs.tests
         trac.prefs.tests.functionalSuite(suite)
         import trac.wiki.tests
@@ -210,7 +212,7 @@ def suite():
         # The db tests should be last since the backup test occurs there.
         import trac.db.tests
         trac.db.tests.functionalSuite(suite)
-    except ImportError, e:
+    except ImportError as e:
         print("SKIP: functional tests (%s)" % e)
         # No tests to run, provide an empty suite.
         suite = unittest.TestSuite()
@@ -218,4 +220,4 @@ def suite():
 
 
 if __name__ == '__main__':
-    unittest.main(defaultTest='suite')
+    unittest.main(defaultTest='test_suite')
