@@ -12,14 +12,15 @@
 # individuals. For the exact contribution history, see the revision
 # history and logs, available at http://trac.edgewall.org/log/.
 
-from trac.tests.functional import *
-from trac.mimeview.rst import has_docutils
-from trac.util import create_file, get_pkginfo
+import os
+import unittest
 
-try:
-    from configobj import ConfigObj
-except ImportError:
-    ConfigObj = None
+from genshi.builder import tag
+
+from trac.mimeview.rst import has_docutils
+from trac.tests.contentgen import random_sentence, random_unique_camel
+from trac.tests.functional import FunctionalTwillTestCaseSetup, tc
+from trac.util import create_file, get_pkginfo
 
 
 class TestWiki(FunctionalTwillTestCaseSetup):
@@ -28,6 +29,39 @@ class TestWiki(FunctionalTwillTestCaseSetup):
         self._tester.create_wiki_page()
 
 
+class TestWikiEdit(FunctionalTwillTestCaseSetup):
+    def runTest(self):
+        """Edit a wiki page."""
+        pagename = self._tester.create_wiki_page()
+        self._tester.edit_wiki_page(pagename)
+        tc.find("Your changes have been saved in version 2")
+        tc.find(r'\(<a href="/wiki/%s\?action=diff&amp;version=2">diff</a>\)'
+                % pagename)
+
+
+class TestWikiDelete(FunctionalTwillTestCaseSetup):
+    def runTest(self):
+        """Delete a wiki page."""
+        name = self._tester.create_wiki_page()
+        self._tester.go_to_wiki(name)
+        tc.formvalue('delete', 'action', 'delete')
+        tc.submit()
+        tc.notfind("The following attachments will also be deleted:")
+        tc.submit('delete', 'delete-confirm')
+        tc.find("The page %s has been deleted." % name)
+        tc.url(self._tester.url)
+
+        name = self._tester.create_wiki_page()
+        filename = self._tester.attach_file_to_wiki(name)
+        self._tester.go_to_wiki(name)
+        tc.formvalue('delete', 'action', 'delete')
+        tc.submit()
+        tc.find("The following attachments will also be deleted:")
+        tc.find(filename)
+        tc.submit('delete', 'delete-confirm')
+        tc.find("The page %s has been deleted." % name)
+        tc.url(self._tester.url)
+
 class TestWikiAddAttachment(FunctionalTwillTestCaseSetup):
     def runTest(self):
         """Add attachment to a wiki page. Test that the attachment
@@ -53,8 +87,7 @@ class TestWikiPageManipulator(FunctionalTwillTestCaseSetup):
         env = self._testenv.get_trac_environment()
         env.config.set('components', plugin_name + '.*', 'enabled')
         env.config.save()
-        create_file(os.path.join(env.path, 'plugins', plugin_name + '.py'),
-"""\
+        create_file(os.path.join(env.plugins_dir, plugin_name + '.py'), """\
 from genshi.builder import tag
 from trac.core import Component, implements
 from trac.util.translation import tag_
@@ -85,7 +118,7 @@ class WikiPageManipulator(Component):
             tc.url(self._tester.url + '/wiki/WikiStart$')
             tc.find("Invalid Wiki page: The page contains invalid markup at"
                     " line <strong>10</strong>.")
-            tc.find("The Wiki page field 'comment' is invalid:"
+            tc.find("The Wiki page field <strong>comment</strong> is invalid:"
                     " The field <strong>comment</strong> cannot be empty.")
         finally:
             env.config.set('components', plugin_name + '.*', 'disabled')
@@ -102,7 +135,7 @@ class TestWikiHistory(FunctionalTwillTestCaseSetup):
         version_link = '<td class="version">[ \t\n]*' \
                        '<a href="/wiki/%(pagename)s\?version=%%(version)s" ' \
                        'title="View this version">%%(version)s[ \t\n]*</a>' \
-                        % {'pagename': pagename}
+                       % {'pagename': pagename}
         tc.find(version_link % {'version': 1})
         tc.find(version_link % {'version': 2})
         tc.formvalue('history', 'old_version', '1')
@@ -115,6 +148,64 @@ class TestWikiHistory(FunctionalTwillTestCaseSetup):
         tc.find(r'<a href="/wiki/%(name)s">%(name)s</a>' % {'name': pagename})
 
 
+class TestWikiReadonlyAttribute(FunctionalTwillTestCaseSetup):
+    """Test the wiki readonly attribute, which is enforce when
+    ReadonlyWikiPolicy is in the list of active permission policies."""
+    def runTest(self):
+        self._tester.logout()
+        self._tester.login('user')
+        page_name = self._tester.create_wiki_page()
+        permission_policies = \
+            self._testenv.get_config('trac', 'permission_policies')
+        readonly_checkbox = '<input type="checkbox" name="readonly" ' + \
+                            'id="readonly" />'
+        attach_button = '<input type="submit" id="attachfilebutton" ' + \
+                        'value="Attach.+file" />'
+        try:
+            # User without WIKI_ADMIN can't set a page read-only
+            tc.formvalue('modifypage', 'action', 'edit')
+            tc.submit()
+            tc.notfind(readonly_checkbox)
+
+            # User with WIKI_ADMIN can set a page read-only
+            # and still edit that page
+            self._testenv.grant_perm('user', 'WIKI_ADMIN')
+            self._tester.go_to_wiki(page_name)
+            tc.formvalue('modifypage', 'action', 'edit')
+            tc.submit()
+            tc.find(readonly_checkbox)
+            tc.formvalue('edit', 'readonly', True)
+            tc.submit('save')
+            tc.go(self._tester.url + '/attachment/wiki/' + page_name)
+            tc.find(attach_button)
+            self._tester.edit_wiki_page(page_name)
+
+            # User without WIKI_ADMIN can't edit a read-only page
+            self._testenv.revoke_perm('user', 'WIKI_ADMIN')
+            self._tester.go_to_wiki(page_name)
+            tc.notfind('<input type="submit" value="Edit this page">')
+            tc.go(self._tester.url + '/attachment/wiki/' + page_name)
+            tc.notfind(attach_button)
+
+            # Read-only checkbox is not present when ReadonlyWikiPolicy
+            # is not in the list of active permission policies
+            pp_list = [p.strip() for p in permission_policies.split(',')]
+            pp_list.remove('ReadonlyWikiPolicy')
+            self._testenv._tracadmin('trac', 'permission_policies',
+                                     ', '.join(pp_list))
+            self._testenv.grant_perm('user', 'WIKI_ADMIN')
+            self._tester.go_to_wiki(page_name)
+            tc.formvalue('modifypage', 'action', 'edit')
+            tc.submit()
+            tc.notfind(readonly_checkbox)
+        finally:
+            self._testenv.set_config('trac', 'permission_policies',
+                                     permission_policies)
+            self._testenv.revoke_perm('user', 'WIKI_ADMIN')
+            self._tester.logout()
+            self._tester.login('admin')
+
+
 class TestWikiRename(FunctionalTwillTestCaseSetup):
     def runTest(self):
         """Test for simple wiki rename"""
@@ -184,7 +275,7 @@ class TestWikiRename(FunctionalTwillTestCaseSetup):
         # this time, the original page is gone
         tc.go(page_url)
         tc.url(page_url)
-        tc.find("The page %s does not exist" % pagename)
+        tc.find("The page %s does not exist" % tag.strong(pagename))
 
 
 class RegressionTestTicket4812(FunctionalTwillTestCaseSetup):
@@ -224,7 +315,7 @@ class ReStructuredTextCodeBlockTest(FunctionalTwillTestCaseSetup):
 #!rst
 .. code-block:: python
 
-    print "123"
+    print("123")
 }}}
 """)
         self._tester.go_to_wiki(pagename)
@@ -297,26 +388,26 @@ class RegressionTestTicket10850(FunctionalTwillTestCaseSetup):
         """Test for regression of http://trac.edgewall.org/ticket/10850"""
         pagename = self._tester.create_wiki_page()
         # colon characters
-        attachment = self._tester.attach_file_to_wiki(
+        self._tester.attach_file_to_wiki(
             pagename, filename='2012-09-11_15:36:40-test.tbz2')
         base_url = self._tester.url
         tc.go(base_url + '/attachment/wiki/' + pagename +
               '/2012-09-11_15:36:40-test.tbz2')
         tc.notfind('Error: Invalid Attachment')
         # backslash characters
-        attachment = self._tester.attach_file_to_wiki(
+        self._tester.attach_file_to_wiki(
             pagename, filename=r'/tmp/back\slash.txt')
         base_url = self._tester.url
         tc.go(base_url + '/attachment/wiki/' + pagename + r'/back\slash.txt')
         tc.notfind('Error: Invalid Attachment')
         # Windows full path
-        attachment = self._tester.attach_file_to_wiki(
+        self._tester.attach_file_to_wiki(
             pagename, filename=r'z:\tmp\windows:path.txt')
         base_url = self._tester.url
         tc.go(base_url + '/attachment/wiki/' + pagename + r'/windows:path.txt')
         tc.notfind('Error: Invalid Attachment')
         # Windows share folder path
-        attachment = self._tester.attach_file_to_wiki(
+        self._tester.attach_file_to_wiki(
             pagename, filename=r'\\server\share\file:name.txt')
         base_url = self._tester.url
         tc.go(base_url + '/attachment/wiki/' + pagename + r'/file:name.txt')
@@ -394,7 +485,7 @@ class RegressionTestTicket11302(FunctionalTwillTestCaseSetup):
     def runTest(self):
         """Test for regression of http://trac.edgewall.org/ticket/11302"""
         pagename = self._tester.create_wiki_page()
-        attachment = self._tester.attach_file_to_wiki(
+        self._tester.attach_file_to_wiki(
             pagename, description="illustrates [./@1#point1]")
         self._tester.go_to_wiki(pagename + '?action=edit')
         tc.find(r'illustrates <a class="wiki"'
@@ -419,11 +510,15 @@ def functionalSuite(suite=None):
         import trac.tests.functional
         suite = trac.tests.functional.functionalSuite()
     suite.addTest(TestWiki())
+    suite.addTest(TestWikiEdit())
+    suite.addTest(TestWikiDelete())
     suite.addTest(TestWikiAddAttachment())
     suite.addTest(TestWikiPageManipulator())
     suite.addTest(TestWikiHistory())
+    suite.addTest(TestWikiReadonlyAttribute())
     suite.addTest(TestWikiRename())
     suite.addTest(RegressionTestTicket4812())
+    suite.addTest(RegressionTestTicket8976())
     suite.addTest(RegressionTestTicket10274())
     suite.addTest(RegressionTestTicket10850())
     suite.addTest(RegressionTestTicket10957())
@@ -435,15 +530,15 @@ def functionalSuite(suite=None):
             suite.addTest(ReStructuredTextWikiTest())
             suite.addTest(ReStructuredTextCodeBlockTest())
         else:
-            print "SKIP: reST wiki tests (docutils has no setuptools metadata)"
+            print("SKIP: reST wiki tests (docutils has no setuptools"
+                  " metadata)")
     else:
-        print "SKIP: reST wiki tests (no docutils)"
-    if ConfigObj:
-        suite.addTest(RegressionTestTicket8976())
-    else:
-        print "SKIP: RegressionTestTicket8976 (ConfigObj not installed)"
+        print("SKIP: reST wiki tests (no docutils)")
     return suite
 
 
+test_suite = functionalSuite
+
+
 if __name__ == '__main__':
-    unittest.main(defaultTest='functionalSuite')
+    unittest.main(defaultTest='test_suite')
